@@ -21,7 +21,7 @@ use Params::Validate ':all';
 use Scalar::Util qw(blessed);
 use Storable qw(dclone);
 
-our $VERSION = '1.02';
+our $VERSION = '1.07';
 
 validation_options(
     on_fail => sub
@@ -165,6 +165,31 @@ sub parse_datetime
             $self->_advance_future('md');
         }
     }
+    elsif ($date_string =~ /^(\d{4}(?:-\d{2}){0,2})T(\d{2}(?::\d{2}){0,2})$/) {
+        my ($date, $time) = ($1, $2);
+
+        my %args;
+
+        @args{qw(year month day)} = split /-/, $date;
+        $args{$_} ||= 01 foreach qw(month day);
+
+        @args{qw(hour minute second)} = split /:/, $time;
+        $args{$_} ||= 00 foreach qw(minute second);
+
+        my $valid_date = $self->_check_date(map $args{$_}, qw(year month day));
+        my $valid_time = $self->_check_time(map $args{$_}, qw(hour minute second));
+
+        if (not $valid_date && $valid_time) {
+            my $type = !$valid_date ? 'date' : 'time';
+            $self->_set_failure;
+            $self->_set_error("(invalid $type)");
+            return $self->_get_datetime_object;
+        }
+
+        $self->_set(%args);
+
+        $self->_set_valid_exp;
+    }
     elsif ($date_string =~ /^([+-]) (\d+?) ([a-zA-Z]+)$/x) {
         my ($prefix, $value, $unit) = ($1, $2, lc $3);
 
@@ -523,16 +548,19 @@ sub _advance_future
         } @{$self->{data}->{$identifier}};
     };
 
+    my $now = exists $self->{Datetime}
+      ? dclone($self->{Datetime})
+      : DateTime->now(time_zone => $self->{Time_zone});
+
     if ((all { /^(?:second|minute|hour)$/ } keys %modified)
         && (exists $self->{modified}{hour} && $self->{modified}{hour} == 1)
-        && $self->{datetime}->hour < DateTime->now(time_zone => $self->{Time_zone})->hour
+        && $self->{datetime}->hour < $now->hour
     ) {
         $self->{postprocess}{day} = 1;
     }
     elsif ($token_contains->('weekdays_all')
         && (exists $self->{modified}{day} && $self->{modified}{day} == 1)
-        && ($self->_Day_of_Week(map $self->{datetime}->$_, qw(year month day))
-         < DateTime->now(time_zone => $self->{Time_zone})->wday)
+        && ($self->_Day_of_Week(map $self->{datetime}->$_, qw(year month day)) < $now->wday)
     ) {
         $self->{postprocess}{day} = 7;
     }
@@ -543,7 +571,7 @@ sub _advance_future
               ? $self->{modified}{day} == 1
                 ? true : false
               : true)
-        && ($self->{datetime}->day_of_year < DateTime->now->day_of_year)
+        && ($self->{datetime}->day_of_year < $now->day_of_year)
     ) {
         $self->{postprocess}{year} = 1;
     }
@@ -614,9 +642,11 @@ sub _set_datetime
 1;
 __END__
 
+=encoding ISO8859-1
+
 =head1 NAME
 
-DateTime::Format::Natural - Create machine readable date/time with natural parsing logic
+DateTime::Format::Natural - Parse informal natural language date/time strings
 
 =head1 SYNOPSIS
 
@@ -624,30 +654,43 @@ DateTime::Format::Natural - Create machine readable date/time with natural parsi
 
  $parser = DateTime::Format::Natural->new;
 
- $date_string  = $parser->extract_datetime($extract_string);
- @date_strings = $parser->extract_datetime($extract_string);
-
  $dt = $parser->parse_datetime($date_string);
  @dt = $parser->parse_datetime_duration($date_string);
 
+ $date_string  = $parser->extract_datetime($extract_string);
+ @date_strings = $parser->extract_datetime($extract_string);
+
  if ($parser->success) {
      # operate on $dt/@dt, for example:
-     printf("%02d.%02d.%4d %02d:%02d:%02d\n", $dt->day,
-                                              $dt->month,
-                                              $dt->year,
-                                              $dt->hour,
-                                              $dt->min,
-                                              $dt->sec);
+     print $dt->strftime('%d.%m.%Y %H:%M:%S'), "\n";
  } else {
      warn $parser->error;
  }
 
  @traces = $parser->trace;
 
+ # examples
+
+ 12:14 PM
+ next tuesday at 2am
+ tomorrow morning
+ 4pm yesterday
+ 10 weeks ago
+
+ 1st tuesday last november
+ 2nd friday in august
+ final thursday in april
+
+ for 3 hours
+ monday to friday
+ 1 April 10 am to 1 May 8am
+
+ jan 24, 2011 12:00
+
 =head1 DESCRIPTION
 
-C<DateTime::Format::Natural> takes a string with a human readable date/time and creates a
-machine readable one by applying natural parsing logic.
+C<DateTime::Format::Natural> parses informal natural language date/time strings.
+In addition, parsable date/time substrings may be extracted from ordinary strings.
 
 =head1 CONSTRUCTOR
 
@@ -685,8 +728,7 @@ Specifies the format of numeric dates, defaults to 'C<d/m/y>'.
 
 =item * C<prefer_future>
 
-Turns ambiguous weekdays/months to their future relatives. Accepts a boolean,
-defaults to false.
+Prefers future time and dates. Accepts a boolean, defaults to false.
 
 =item * C<time_zone>
 
@@ -704,7 +746,7 @@ which may be selectively changed.
 
 =head2 parse_datetime
 
-Returns a L<DateTime> object constructed from a human readable date/time string.
+Returns a L<DateTime> object constructed from a natural language date/time string.
 
  $dt = $parser->parse_datetime($date_string);
  $dt = $parser->parse_datetime(string => $date_string);
@@ -719,7 +761,7 @@ The date string.
 
 =head2 parse_datetime_duration
 
-Returns one or two L<DateTime> objects constructed from a human readable
+Returns one or two L<DateTime> objects constructed from a natural language
 date/time string which may contain timespans/durations. I<Same> interface
 and options as C<parse_datetime()>, but should be explicitly called in
 list context.
@@ -762,13 +804,13 @@ one string is commonly returned for durations. Useful as a debugging aid.
 The grammar handling has been rewritten to be easily extendable and hence
 everybody is encouraged to propose sensible new additions and/or changes.
 
-See the classes C<DateTime::Format::Natural::Lang::[language_code]> if
-you're intending to hack a bit on the grammar guts.
+See the class L<DateTime::Format::Natural::Lang::EN> if you're intending
+to hack a bit on the grammar guts.
 
 =head1 EXAMPLES
 
-See the classes C<DateTime::Format::Natural::Lang::[language_code]> for an
-overview of currently valid input.
+See the class L<DateTime::Format::Natural::Lang::EN> for an overview of
+currently valid input.
 
 =head1 BUGS & CAVEATS
 
@@ -823,6 +865,10 @@ valuable suggestions and patches:
  Chifung Fan
  Xiao Yafeng
  Roman Filippov
+ David Steinbrunner
+ Debian Perl Group
+ Tim Bunce
+ Ricardo Signes
 
 =head1 SEE ALSO
 
