@@ -12,14 +12,7 @@ use constant MORNING   => '08';
 use constant AFTERNOON => '14';
 use constant EVENING   => '20';
 
-our $VERSION = '1.46';
-
-my $multiply_by = sub
-{
-    my ($value, $opts) = @_;
-    return $value * $opts->{multiply_by} if exists $opts->{multiply_by};
-    return $value;
-};
+our $VERSION = '1.42';
 
 sub _no_op
 {
@@ -33,7 +26,7 @@ sub _ago_variant
     my $self = shift;
     $self->_register_trace;
     my $opts = pop;
-    $self->_subtract($opts->{unit} => $multiply_by->(shift, $opts));
+    $self->_subtract($opts->{unit} => shift);
 }
 
 sub _now_variant
@@ -45,7 +38,7 @@ sub _now_variant
     $self->_add_or_subtract({
         when  => $when,
         unit  => $opts->{unit},
-        value => $multiply_by->($value, $opts),
+        value => $value,
     });
 }
 
@@ -95,11 +88,10 @@ sub _hourtime_variant
     my $hours = $opts->{hours} || 0;
     if ($self->_valid_time(hour => $hours)) {
         $self->_set(hour => $hours);
-        $self->{datetime}->set(minute => 0, second => 0, nanosecond => 0);
         $self->_add_or_subtract({
             when  => $when,
-            unit  => $opts->{unit},
-            value => $multiply_by->($value, $opts),
+            unit  => 'hour',
+            value => $value,
         });
     }
 }
@@ -183,7 +175,7 @@ sub _unit_variant
     $self->_add_or_subtract({
         when  => $when,
         unit  => $opts->{unit},
-        value => $multiply_by->(1, $opts),
+        value => 1,
     });
 }
 
@@ -204,7 +196,7 @@ sub _in_count_variant
     my $self = shift;
     $self->_register_trace;
     my $opts = pop;
-    $self->_add_or_subtract($opts->{unit} => $multiply_by->(shift, $opts));
+    $self->_add_or_subtract($opts->{unit} => shift);
 }
 
 sub _month_variant
@@ -254,19 +246,20 @@ sub _count_weekday_variant_month
     }
 }
 
-sub _daytime_unit_variant
+sub _daytime_hours_variant
 {
     my $self = shift;
     $self->_register_trace;
     my $opts = pop;
-    my ($value, $when, $days) = @_;
-    $self->_add(day => $days);
-    $self->{datetime}->set(hour => 0, minute => 0, second => 0, nanosecond => 0);
-    $self->_add_or_subtract({
-        when  => $when,
-        unit  => $opts->{unit},
-        value => $multiply_by->($value, $opts),
-    });
+    my ($hours, $when, $days) = @_;
+    my %values = (
+        -1 => { day => ($days - 1), hours => (24 - $hours) },
+         1 => { day => $days,       hours => (0  + $hours) },
+    );
+    if ($self->_valid_time(hour => $values{$when}->{hours})) {
+        $self->_add(day => $values{$when}->{day});
+        $self->_set(hour => $values{$when}->{hours});
+    }
 }
 
 # wrapper for <time> AM/PM
@@ -290,9 +283,8 @@ sub _at_time
     my $self = shift;
     my $opts = pop;
     my ($time) = @_;
-    my @units = qw(hour minute second nanosecond);
-    my %values = map { shift @units => $_ } split /[:\.]/, $time;
-    $values{nanosecond} *= 1_000_000 if exists $values{nanosecond}; # milli to nano
+    my @units = qw(hour minute second);
+    my %values = map { shift @units => $_ } split /:/, $time;
     if ($self->_valid_time(%values)) {
         $self->_set(%values);
     }
